@@ -1,11 +1,17 @@
+{-# LANGUAGE CPP #-}
 module Imports (module Imports) where
 
 import           Control.Applicative as Imports
 import           Control.Arrow as Imports ((>>>), (&&&))
 import           Control.Exception as Imports (Exception(..))
 import           Control.Monad as Imports
+import           Control.Monad.IO.Class as Imports
 import           Data.Bifunctor as Imports
+#if MIN_VERSION_base(4,20,0)
+import           Data.List as Imports hiding (List, sort, nub)
+#else
 import           Data.List as Imports hiding (sort, nub)
+#endif
 import           Data.Monoid as Imports (Monoid(..))
 import           Data.Semigroup as Imports (Semigroup(..))
 import           Data.String as Imports
